Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1250)

Unified Diff: third_party/WebKit/Source/core/events/PointerEventFactory.h

Issue 1800143002: Notify Blink about start of gesture scroll through a queued event. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 4 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/core/events/PointerEventFactory.h
diff --git a/third_party/WebKit/Source/core/events/PointerEventFactory.h b/third_party/WebKit/Source/core/events/PointerEventFactory.h
index 9e342217270e39a2f8f6dfefbc6292902bd4f70a..0644c4e448c251e80b8904d2eac711b4b8a6a185 100644
--- a/third_party/WebKit/Source/core/events/PointerEventFactory.h
+++ b/third_party/WebKit/Source/core/events/PointerEventFactory.h
@@ -40,7 +40,7 @@ public:
const double clientX, const double clientY);
PassRefPtrWillBeRawPtr<PointerEvent> createPointerCancel(
- const PlatformTouchPoint&);
+ const int pointerId, const WebPointerProperties::PointerType);
PassRefPtrWillBeRawPtr<PointerEvent> create(
PassRefPtrWillBeRawPtr<PointerEvent>,
@@ -50,11 +50,13 @@ public:
// Clear all the existing ids.
void clear();
- // Returns true if pointerEvent is removed. When a pointerEvent with a
- // particular id is removed that id is considered free even though there
- // might have been other PointerEvents that were generated with the same id
- // before.
- bool remove(const PassRefPtrWillBeRawPtr<PointerEvent>);
+ // When a particular pointerId is removed that id is considered free even
+ // though there might have been other PointerEvents that were generated with
+ // the same id before.
+ bool remove(const int);
+
+ // Returns all ids of the given pointerType.
+ WillBeHeapVector<int> getPointerIdsOfType(WebPointerProperties::PointerType);
// Returns whether a pointer id exists and active
bool isActive(const int);

Powered by Google App Engine
This is Rietveld 408576698